# Generated by Django 2.2.17 on 2021-02-10 08:13

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_uploader', '0012_file_document'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='file',
            name='document',
        ),
        migrations.RemoveField(
            model_name='file',
            name='is_bytes',
        ),
        migrations.RemoveField(
            model_name='file',
            name='object_content',
        ),
    ]
