{% extends 'sib_base.html' %}

{% load static %}

{% block content %}
    <form method="post" enctype="multipart/form-data">
        {% csrf_token %}
        <input type="file" name="myfile">
        <button type="submit">Upload</button>
    </form>

    {% if uploaded_file_url %}
        <p>File uploaded at: <a href="{{ uploaded_file_url }}">{{ uploaded_file_url }}</a></p>
    {% endif %}

    <p><a href="{% url 'home' %}">Return to home</a></p>
{% endblock %}
