<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8" />
    <meta name="viewport" content="width=device-width, initial-scale=1.0" />
    <meta http-equiv="X-UA-Compatible" content="ie=edge" />
    <title>SIB test: local file</title>
    <script type="module" src="http://unpkg.com/@startinblox/core"></script>
</head>

<body>
    <main id="content">
        {% block content %}{% endblock %}
    </main>
</body>
</html>

