# Generated by Django 2.2.17 on 2021-02-08 08:18

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_uploader', '0009_auto_20210202_1510'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='document',
            options={'default_permissions': ['add', 'change', 'delete', 'view', 'control']},
        ),
        migrations.AlterModelOptions(
            name='file',
            options={'default_permissions': ['add', 'change', 'delete', 'view', 'control']},
        ),
        migrations.AddField(
            model_name='file',
            name='is_bytes',
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name='file',
            name='object_content',
            field=models.BinaryField(blank=True),
        ),
        migrations.AlterField(
            model_name='file',
            name='stored_url',
            field=models.CharField(blank=True, max_length=255),
        ),
    ]
