# Generated by Django 2.2.17 on 2021-02-16 15:44

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_uploader', '0013_auto_20210210_0913'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='document',
            options={'default_permissions': ['add', 'change', 'delete', 'view', 'control']},
        ),
        migrations.AlterModelOptions(
            name='file',
            options={'default_permissions': ['add', 'change', 'delete', 'view', 'control']},
        ),
    ]
