{% extends 'sib_base.html' %}

{% block content %}
    <form method="post" enctype="multipart/form-data">
        {% csrf_token %}
        {{ form.as_p }}
        <button type="submit">Upload</button>
    </form>

    <p><a href="{% url 'home' %}">Return to home</a></p>
{% endblock %}
