# Generated by Django 2.2.17 on 2021-02-09 08:14

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_uploader', '0011_auto_20210208_1801'),
    ]

    operations = [
        migrations.AddField(
            model_name='file',
            name='document',
            field=models.FileField(default=None, upload_to='media/'),
        ),
    ]
