{% extends 'sib_base.html' %}

{% load static %}

{% block content %}
    <h3><tt>&lt;solid-form-file&gt;</tt> only</h3>
    <!-- <solid-form-file
            label="upload (wrong url):"
            upload-url="http://127.0.0.1/upload"
    ></solid-form-file> -->
    <solid-form-file label="upload:" upload-url="/upload/"></solid-form-file>

    <h3><tt>&lt;solid-form-file&gt;</tt> in <tt>&lt;solid-form&gt;</tt></h3>
    <solid-form
            data-src="https://api.test-paris.happy-dev.fr/accounts/9/"
            fields="user.username, picture"
            upload-url-picture="/upload/"
    ></solid-form>

    <p><a href="{% url 'home' %}">Return to home</a></p>
{% endblock %}
