# Generated by Django 2.2.17 on 2021-02-02 09:58

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_uploader', '0007_auto_20210128_0724'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='document',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'control')},
        ),
        migrations.AlterModelOptions(
            name='file',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'control')},
        ),
    ]
