# Generated by Django 2.2.17 on 2021-02-02 14:10

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_uploader', '0008_auto_20210202_1058'),
    ]

    operations = [
        migrations.AddField(
            model_name='file',
            name='content_type',
            field=models.CharField(default='None', max_length=255),
        ),
        migrations.AddField(
            model_name='file',
            name='object_content',
            field=models.BinaryField(default=b'None'),
        ),
    ]
